@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 Rumma & Ko Ltd
+# Copyright 2013-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Adds blogging functionality. See :doc:`/plugins/blogs`.
@@ -12,7 +12,7 @@ class Plugin(Plugin):
 
     verbose_name = _("Blog")
 
-    needs_plugins = ['lino_xl.lib.topics', 'lino.modlib.office']
+    needs_plugins = ['lino_xl.lib.topics', 'lino_xl.lib.albums', 'lino.modlib.office']
 
     def setup_main_menu(self, site, user_type, m):
         # mg = self.get_menu_group()
@@ -34,6 +34,13 @@ class Plugin(Plugin):
     def setup_quicklinks(self, tb):
         tb.add_action("blogs.MyEntries.insert", label=_("New blog entry"))
 
+    def get_dashboard_items(self, user):
+        yield self.site.models.blogs.LatestEntries
+        # yield self.site.models.blogs.PublicEntries
+        # from lino.core.dashboard import ActorItem
+        # yield ActorItem(
+        #     self.site.models.blogs.LatestEntries, display_mode="list")
+
 
     # def get_dashboard_items(self, user):
     #     from lino.core.dashboard import ActorItem
