@@ -725,9 +725,9 @@ class Role(dd.Model, Addressable):
 
     def as_paragraph(self, ar):
         if ar.is_obvious_field('person'):
-            txt = ar.obj2str(self.company)
+            txt = ar.obj2htmls(self.company)
         elif ar.is_obvious_field('company'):
-            txt = ar.obj2str(self.person)
+            txt = ar.obj2htmls(self.person)
         else:
             return super().__str__()
         if self.type is not None:
