@@ -24,6 +24,7 @@ from lino_xl.lib.excerpts.mixins import Certifiable
 from lino_xl.lib.excerpts.mixins import ExcerptTitle
 from lino.modlib.users.mixins import UserAuthored
 from lino.modlib.printing.mixins import Printable
+from lino.modlib.memo.mixins import MemoReferrable
 # from lino.modlib.printing.utils import PrintableObject
 from lino_xl.lib.cal.mixins import Reservation
 from lino_xl.lib.cal.choicelists import Recurrencies
@@ -167,7 +168,7 @@ class Line(Referrable, Duplicable, ExcerptTitle, ContactRelated):
             'excerpts')
 
 
-class Course(Reservation, Duplicable, Printable):
+class Course(Reservation, Duplicable, Printable, MemoReferrable):
 
     class Meta:
         app_label = 'courses'
@@ -177,6 +178,7 @@ class Course(Reservation, Duplicable, Printable):
         # verbose_name = _("Event")
         # verbose_name_plural = _('Events')
 
+    memo_command = 'course'
     site_field_name = 'room'
 
     # line = dd.ForeignKey('courses.Line', null=True, blank=True)
@@ -698,40 +700,40 @@ dd.inject_field('system.SiteConfig', 'pupil_guestrole',
 
 
 
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-
-    if not sender.is_installed('memo'):
-        return
-
-    Course = sender.models.courses.Course
-
-    def cmd(parser, s, cmdname, usages):
-
-        pk = s
-        txt = None
-
-        ar = parser.context['ar']
-        kw = dict()
-        # dd.logger.info("20161019 %s", ar.renderer)
-        pk = int(pk)
-        obj = Course.objects.get(pk=pk)
-        # try:
-        # except model.DoesNotExist:
-        #     return "[{} {}]".format(name, s)
-        if txt is None:
-            txt = "{0}".format(obj.name)
-            kw.update(title=obj.name)
-        e = ar.obj2html(obj, txt, **kw)
-        # return str(ar)
-        return tostring(e)
-
-    sender.plugins.memo.parser.register_django_model(
-        'course', Course,
-        cmd=cmd,
-        # title=lambda obj: obj.name
-    )
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     Course = sender.models.courses.Course
+#
+#     def cmd(parser, s, cmdname, usages):
+#
+#         pk = s
+#         txt = None
+#
+#         ar = parser.context['ar']
+#         kw = dict()
+#         # dd.logger.info("20161019 %s", ar.renderer)
+#         pk = int(pk)
+#         obj = Course.objects.get(pk=pk)
+#         # try:
+#         # except model.DoesNotExist:
+#         #     return "[{} {}]".format(name, s)
+#         if txt is None:
+#             txt = "{0}".format(obj.name)
+#             kw.update(title=obj.name)
+#         e = ar.obj2html(obj, txt, **kw)
+#         # return str(ar)
+#         return tostring(e)
+#
+#     sender.plugins.memo.parser.register_django_model(
+#         'course', Course,
+#         cmd=cmd,
+#         # title=lambda obj: obj.name
+#     )
 
 
 from .ui import *
