@@ -1,24 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2015 Rumma & Ko Ltd
+# Copyright 2013-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
-A rather specialized app used for :mod:`lino.projects.events`.
-"""
-
-
-# Copyright 2008-2015 Rumma & Ko Ltd
-# License: GNU Affero General Public License v3 (see file COPYING for details)
-
-"""
-Adds functionality for managing foos.
-
-.. autosummary::
-   :toctree:
-
-    models
-    fixtures.vor
-
+A rather specialized plugin used only by :mod:`lino_book.projects.events`.
+See :ref:`book.specs.events`
 """
 
 from lino import ad, _
@@ -38,4 +24,3 @@ class Plugin(ad.Plugin):
     def setup_main_menu(self, site, user_type, m):
         m = m.add_menu(self.app_label, self.verbose_name)
         m.add_action('events.Events')
-
