@@ -2,7 +2,7 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-"""See :doc:`/specs/sepa`.
+"""See :doc:`/plugins/sepa`.
 
 .. autosummary::
    :toctree:
