@@ -15,7 +15,7 @@ from lino_xl.lib.tickets.roles import Triager
 
 class WorkerAction(dd.Action):
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
     readonly = False
     required_roles = dd.login_required(Worker)
 
@@ -105,7 +105,7 @@ class StartTicketSession(WorkerAction):
     label = u"▶"  # BLACK RIGHT-POINTING TRIANGLE (U+25B6)
     # icon_name = 'emoticon_smile'
     # show_in_workflow = True
-    # show_in_bbar = False
+    # show_in_toolbar = False
     readonly = True
     # required_roles = dd.login_required(Worker)
 
@@ -173,7 +173,7 @@ class PrintActivityReport(DirectPrintAction):
 
 class ShowMySessionsByDay(dd.Action):
     label = _("Day's work")
-    show_in_bbar = True
+    show_in_toolbar = True
     sort_index = 60
     icon_name = 'calendar'
 
