@@ -501,14 +501,17 @@ class TicketsByReport(Tickets, DurationReport):
             return
         pv = ar.param_values
 
-        pv.update(start_date=mi.start_date, end_date=mi.end_date)
+        # pv.update(start_date=mi.start_date, end_date=mi.end_date)
+        pv.update(start_date=mi.invoicing_min_date, end_date=mi.invoicing_max_date)
         # pv.update(interesting_for=mi.interesting_for)
-        pv.update(interesting_for=mi.company)
+        # pv.update(interesting_for=mi.company)
         pv.update(observed_event=TicketEvents.working)
 
-        spv = dict(start_date=mi.start_date, end_date=mi.end_date)
+        # spv = dict(start_date=mi.start_date, end_date=mi.end_date)
+        spv = dict(start_date=mi.invoicing_min_date, end_date=mi.invoicing_max_date)
         spv.update(observed_event=dd.PeriodEvents.started)
-        spv.update(user=mi.user)
+        spv.update(company=mi.company)  # interesting_for
+        # spv.update(user=mi.user)
         qs = super().get_request_queryset(ar)
         for obj in qs:
             sar = SessionsByTicket.request(
@@ -711,7 +714,7 @@ class WorkedHours(DaysTable, dd.VentilatingTable):
     def row_as_paragraph(cls, ar, row):
         txt = ar.add_detail_link(row, str(row))
         tickets = [
-            ar.obj2str(t, "#{0}".format(t.id), title=t.summary)
+            ar.obj2htmls(t, "#{0}".format(t.id), title=t.summary)
             for t in row._tickets]
         if len(tickets) > 0:
             txt += " ({})".format(", ".join(tickets))
